@@ -12,8 +12,7 @@ _DATA_TYPES = {'i': FORTRAN_DATA_TYPE_INTEGER, 'f': FORTRAN_DATA_TYPE_FLOAT,
 
 
 def _get_dtype_output_format(d, n):
-    """
-    Returns the correct output format needed to create a numpy dtype depending on input.
+    """Returns the correct output format needed to create a numpy dtype depending on input.
     """
     if d == 'c':
         return str(n)
@@ -23,8 +22,7 @@ def _get_dtype_output_format(d, n):
 
 
 def new_raw(data_structure: Sequence[Tuple[str, Union[int, str]]]) -> str:
-    """
-    Creates the string definition for a fortran-compliant numpy dtype to read in binary fortran data.
+    """Creates the string definition for a fortran-compliant numpy dtype to read in binary fortran data.
 
     :param data_structure: Tuple consisting of tuples with 2 elements each where the first element
      is a char ('i', 'f', 'c' or '{}') representing the primitive data type to be used and the
@@ -36,8 +34,7 @@ def new_raw(data_structure: Sequence[Tuple[str, Union[int, str]]]) -> str:
 
 
 def new(data_structure: Sequence[Tuple[str, Union[int, str]]]) -> np.dtype:
-    """
-    Creates a fortran-compliant numpy dtype to read in binary fortran data.
+    """Creates a fortran-compliant numpy dtype to read in binary fortran data.
 
     :param data_structure: Tuple consisting of tuples with 2 elements each where the first element
      is a char ('i', 'f' or 'c') representing the primitive data type to be used and the second
@@ -48,8 +45,7 @@ def new(data_structure: Sequence[Tuple[str, Union[int, str]]]) -> np.dtype:
 
 
 def combine(*dtypes: np.dtype):
-    """
-    Combines multiple numpy dtypes into one.
+    """Combines multiple numpy dtypes into one.
 
     :param dtypes: An arbitrary amount of numpy dtype objects can be provided.
     :returns: The newly created numpy dtype.
@@ -73,8 +69,7 @@ HAS_POST_BORDER = FORTRAN_BACKWARD
 
 
 def read(infile: BinaryIO, dtype: np.dtype, n: int):
-    """
-    Convenience function to read in binary data from a file using a numpy dtype.
+    """Convenience function to read in binary data from a file using a numpy dtype.
 
     :param infile: Already opened binary IO stream.
     :param dtype: Numpy dtype object.
